@@ -1,7 +1,7 @@
 import supervisely as sly
 from supervisely.nn.tracker.base_tracker import BaseTracker
 from supervisely import Annotation, VideoAnnotation
-
+from supervisely.annotation.label import LabelingStatus
 from dataclasses import dataclass
 from types import SimpleNamespace
 from typing import List, Dict, Tuple, Any, Optional
@@ -239,7 +239,7 @@ class BotSortTracker(BaseTracker):
                 
                 video_object = video_objects[track_id]
                 rect = sly.Rectangle(top=y1, left=x1, bottom=y2, right=x2)
-                frame_figures.append(sly.VideoFigure(video_object, rect, frame_idx, track_id=str(track_id)))
+                frame_figures.append(sly.VideoFigure(video_object, rect, frame_idx, track_id=str(track_id), status=LabelingStatus.AUTO))
             
             frames.append(sly.Frame(frame_idx, frame_figures))
 
